// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// October 2000
//
#ifndef EPICPROC_H
#define EPICPROC_H


#include<EpicProcState.h>

class EpicProc {
  
public:
  
  void process();
  void init();
  virtual ~EpicProc();

private:

  virtual void init_pimpl() = 0;
  void setOalInstrument() const;
  void transferParameter(const std::string& par, ParameterInfo& task) const;

  void selectExposures();
  void processAttitude();
  void processHk();
  //AI(26/04/2005): Convert to a pure virtual method. Because the chains process have change to
  //much one from each other, now it is completely impossible to maintain the 
  //same process Exposure algorithm for both instruments. So, from now on, each
  //instrument has its own algortihm to process the images.
  virtual void processExposure(Proc::ScienceExposure&) = 0 ;

  virtual void preProcessExposure(Proc::ScienceExposure&);
  virtual void preProcessExposureHook(Proc::ScienceExposure&);

  virtual void runepnoise(const std::vector<std::string>& el,
		  	  	  	  	  Proc::ScienceExposure&);

  virtual void frames(const OdfSet *) = 0;

  virtual bool couldRunBadpixfindOn(const OdfSet *) = 0;
  virtual void preBadpixelsHook(const OdfSet *);

  virtual void badpix(const OdfSet *) = 0;

  virtual void events(const OdfSet *) = 0;

  virtual void finalizeHook(const OdfSet *);

  virtual void screenExposure(const Proc::ScienceExposure&);

  virtual void postProcessExposure(Proc::ScienceExposure&);
  virtual void postProcessExposureHook(Proc::ScienceExposure&);

  virtual void combine(const std::vector<std::string>& el,
		       const Proc::ScienceExposure& exp);

  virtual void combineHook(ParameterInfo& evlistcompars) = 0;


protected:

  //AI: To allow processExposure to access to this methods.

  virtual void badpixfind(const OdfSet *);
  virtual void badpixels(const OdfSet *);
  void attitude(const OdfSet *);
  virtual void finalize(const OdfSet *);
  virtual void filter(const OdfSet *);

  // pimpl
  EpicProcState * ePS_;
};

#endif
