// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// October 2000
//
#ifndef EMPROC_H
#define EMPROC_H


#include<EpicProc.h>
#include<Proc.h>

class EpicProcState;

class Emproc : public EpicProc {
public:
  Emproc(Xmm::Instrument);
  
private:
  
  void init_pimpl();
  
  void preProcessExposureHook(Proc::ScienceExposure&);
  //  void postProcessExposureHook(Proc::ScienceExposure&);
  
  //AI(26/04/2005): New method to handle with the exposure process.
  void processExposure(Proc::ScienceExposure&);

  //AI: New method that calls the new task: emeventsproj and embadpixfind
  void badPixelsSearch(const OdfSet *);

  void mergeIntermediateResults(Proc::ScienceExposure&);
  
  //AI: Set the values for emosimgcolnames and emosimgcoltypes
  void combineMergeEvents(ParameterInfo&);

  //AI: Call to ebadpixupdate task
  void badPixUpdate();

  // Screening
  bool makeFlareTs();
  void addFracExp(double timeBin);

  void tsToGTI();

  void testFlareGTI();

  void findFinalBadPixels(const OdfSet *);

  void frames(const OdfSet *);
  bool couldRunBadpixfindOn(const OdfSet *);
  virtual void preBadpixelsHook(const OdfSet *);
  void badpix(const OdfSet *);
  void events(const OdfSet *);
  
  //  void finalize(const OdfSet *);
  void finalizeHook(const OdfSet *);  
  void screenExposure(const Proc::ScienceExposure&);

  //  void postProcessExposure(Proc::ScienceExposure& exp);
  void combineHook(ParameterInfo&);
};

#endif
