// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//---------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//      checkpn.cc: --- test harness for epproc
//
//
//      CHANGE HISTORY:
//           AI, 2004-06-07: 1.0.0: - first version
//
//      REFERENCES:
//
//      AUTHOR:
//           A. Ibarra (AI), Mon Jun  7 11:39:01 CEST 2004
//
//      COMMENTS:
//           Due to problems with DAL and MacOS, we have had to change the test harness
//           for epproc package. The old test harness programs were written in perl, now
//           the test harness programs have been recoded in C++.
//     
//

#include <iostream>
#include <Dal.h>
#include <cassert>
#include <string>
#include <vector>

int main (int argc, char* argv[])
{

  if (argc != 2 )
    {
      std::cerr<<"Usage: "<<argv[0]<<" <expr> \n";
      return 1;
    }
  
  std::vector <std::string>  tables;
  tables.push_back("EVENTS");
  tables.push_back("EXPOSU01");
  tables.push_back("BADPIX01");
  tables.push_back("STDGTI01");
  tables.push_back("CALINDEX");

  std::string name(argv[1]);
  DataSet* set = dataSetServer->open(name, Dal::Read);

  for (unsigned i=0; i<tables.size() ; i++)
    {      
      if( set->table(tables[i]) )
	std::cout << tables[i] << std::endl; 
      else
	{
	  std::cerr << "table: tables[i] missing " << std::endl;
	  return 1;
	}
    }

  Table* tabEvents = set->table("EVENTS"); 
  assert((tabEvents->rows() > 700) && (tabEvents->rows() < 770) );

  // Due to the continuous changes in the CALINDEX table,
  // we have removed this check (05/10/04)

  // Table* tabIndex = set->table("CALINDEX");
  //assert(tabIndex->rows() == 101);
  

  dataSetServer->close(set);  
  return 0;
}
